# libnbd Python bindings
# Copyright (C) 2010-2019 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

import nbd

h = nbd.NBD()

messages = []


def f(id, context, msg):
    global messages

    assert id == 42
    messages.append(msg)


h.set_debug_callback(lambda *args: f(42, *args))

h.connect_command(["nbdkit", "-s", "--exit-with-parent", "null"])
h.shutdown()

# Try to trigger garbage collection of h
h = None

print("%r" % messages)
